@@ -8,8 +8,8 @@ class Kontaktart(StrEnum):
     Art des Kontaktes zwischen Geschäftspartnern.
     """
 
-    ANSCHREIBEN = "ANSCHREIBEN"
-    TELEFONAT = "TELEFONAT"
-    FAX = "FAX"
-    E_MAIL = "E_MAIL"
-    SMS = "SMS"
+    ANSCHREIBEN = "ANSCHREIBEN"  #: Anschreiben
+    TELEFONAT = "TELEFONAT"  #: Telefonat
+    FAX = "FAX"  #: Fax
+    E_MAIL = "E_MAIL"  #: Email
+    SMS = "SMS"  #: SMS
