@@ -3,41 +3,22 @@ Contains validators for BO s and COM s classes.
 """
 import re
 from datetime import datetime
-from typing import Optional, Protocol
-
-import attrs.validators
+from typing import Any, Dict, Optional, Protocol
 
 from bo4e.enum.aufabschlagstyp import AufAbschlagstyp
 
-
 # pylint: disable=unused-argument
-def check_list_length_at_least_one(instance, attribute, value):
-    """
-    Check that minimal list length is at least one.
-    """
-    if len(value) < 1:
-        raise ValueError(f"List {attribute.name} must not be empty.")
+from bo4e.enum.waehrungseinheit import Waehrungseinheit
 
 
-def einheit_only_for_abschlagstyp_absolut(instance, attribute, value):
+def einheit_only_for_abschlagstyp_absolut(cls, value: Waehrungseinheit, values: Dict[str, Any]) -> Waehrungseinheit:  # type: ignore[no-untyped-def]
     """
     Check that einheit is only there if abschlagstyp is absolut.
     Currently, (2021-12-15) only used in COM AufAbschlag.
     """
-    if value and (not instance.auf_abschlagstyp or (instance.auf_abschlagstyp != AufAbschlagstyp.ABSOLUT)):
+    if value and (not values["auf_abschlagstyp"] or (values["auf_abschlagstyp"] != AufAbschlagstyp.ABSOLUT)):
         raise ValueError("Only state einheit if auf_abschlagstyp is absolute.")
-
-
-# pylint: disable=unused-argument
-def check_list_length_is_one_or_two(instance, attribute, value):
-    """
-    Check if list length is one or two.
-    So far only used in StandorteigenschaftenGas.
-    """
-    if len(value) == 0:
-        raise ValueError(f"{attribute.name} must not be empty.")
-    if len(value) > 2:
-        raise ValueError(f"Maximum number of {attribute.name} is 2.")
+    return value
 
 
 # pylint:disable=too-few-public-methods
@@ -46,53 +27,55 @@ class _VonBisType(Protocol):
     a protocol for all classes that have an inclusive start and exclusive end
     """
 
-    def _get_inclusive_start(self) -> Optional[datetime]:
+    @staticmethod
+    def _get_inclusive_start(values: Dict[str, Any]) -> Optional[datetime]:
         """
         should return the inclusive start of the timeslice
         """
 
-    def _get_exclusive_end(self) -> Optional[datetime]:
-        """
-        should return the exclusive end of the timeslice
-        """
+    # def _get_exclusive_end(self) -> Optional[datetime]:
+    #     """
+    #     should return the exclusive end of the timeslice
+    #     """
 
 
-def check_bis_is_later_than_von(instance: _VonBisType, attribute, value):
+def check_bis_is_later_than_von(cls, value: datetime, values: Dict[str, Any]):  # type: ignore[no-untyped-def]
     """
     assert that 'bis' is later than 'von'
     """
     # we want access to private methods here because these helper methods should be "hidden"
-    start = instance._get_inclusive_start()  # pylint: disable=protected-access
-    end = instance._get_exclusive_end()  # pylint: disable=protected-access
+    start = cls._get_inclusive_start(values)  # pylint: disable=protected-access
+    end = value
     if start and end and not end >= start:
         raise ValueError(f"The end '{end}' has to be later than the start '{start}'")
+    return value
 
 
 # pylint:disable=line-too-long
 #: a regular expression that should match all OBIS Kennziffern
 OBIS_PATTERN = r"((1)-((?:[0-5]?[0-9])|(?:6[0-5])):((?:[1-8]|99))\.((?:6|8|9|29))\.([0-9]{1,2})|(7)-((?:[0-5]?[0-9])|(?:6[0-5])):(.{1,2})\.(.{1,2})\.([0-9]{1,2}))"
-#: an attr validator
-obis_validator = attrs.validators.matches_re(OBIS_PATTERN)
+# TODO: Maybe create custom data type for OBIS. See https://pydantic-docs.helpmanual.io/usage/types/#custom-data-types
 
-_malo_id_pattern = re.compile(r"^[1-9][\d]{10}$")
+_malo_id_pattern = re.compile(r"^[1-9]\d{10}$")
 
 
 # pylint: disable=unused-argument
-def validate_marktlokations_id(self, marktlokations_id_attribute, value):
+def validate_marktlokations_id(cls, marktlokations_id: str, values: Dict[str, Any]) -> str:  # type: ignore[no-untyped-def]
     """
     A validator for marktlokations IDs
     """
-    if not value:
+    if not marktlokations_id:
         raise ValueError("The marktlokations_id must not be empty.")
-    if not _malo_id_pattern.match(value):
-        raise ValueError(f"The {marktlokations_id_attribute.name} '{value}' does not match {_malo_id_pattern.pattern}")
-    expected_checksum = _get_malo_id_checksum(value)
-    actual_checksum = value[10:11]
+    if not _malo_id_pattern.match(marktlokations_id):
+        raise ValueError(f"The Marktlokations-ID '{marktlokations_id}' does not match {_malo_id_pattern.pattern}")
+    expected_checksum = _get_malo_id_checksum(marktlokations_id)
+    actual_checksum = marktlokations_id[10:11]
     if expected_checksum != actual_checksum:
         # pylint: disable=line-too-long
         raise ValueError(
-            f"The {marktlokations_id_attribute.name} '{value}' has checksum '{actual_checksum}' but '{expected_checksum}' was expected."
+            f"The Marktlokations-ID '{marktlokations_id}' has checksum '{actual_checksum}' but '{expected_checksum}' was expected."
         )
+    return marktlokations_id
 
 
 def _get_malo_id_checksum(malo_id: str) -> str:
