@@ -3,7 +3,7 @@ import re
 from pathlib import Path
 from typing import List, Optional, TypeVar
 
-import pytest  # type:ignore[import]
+import pytest
 
 from bo4e.enum import anrede
 from bo4e.enum.strenum import StrEnum
