@@ -1,6 +1,6 @@
 from decimal import Decimal
 
-import pytest  # type:ignore[import]
+import pytest
 from pydantic import ValidationError
 
 from bo4e.com.geokoordinaten import Geokoordinaten
