@@ -1,7 +1,7 @@
 import json
 
 import pytest
-from py._path.local import LocalPath
+from py._path.local import LocalPath  # type:ignore[import]
 from pydantic import ValidationError
 
 from bo4e.bo.geschaeftspartner import Geschaeftspartner
