@@ -1,10 +1,10 @@
 from typing import Any, Dict
 
-import pytest  # type:ignore[import]
+import pytest
 from pydantic import ValidationError
 
 from bo4e.com.standorteigenschaftenstrom import StandorteigenschaftenStrom
-from tests.serialization_helper import assert_serialization_roundtrip  # type:ignore[import]
+from tests.serialization_helper import assert_serialization_roundtrip
 
 example_standorteigenschaften_strom = StandorteigenschaftenStrom(
     regelzone="Transnet BW",
