@@ -1,6 +1,6 @@
 import datetime
 
-import pytest  # type:ignore[import]
+import pytest
 from pydantic import ValidationError
 
 from bo4e.bo.tarifpreisblatt import Tarifpreisblatt
@@ -11,16 +11,16 @@ from bo4e.enum.sparte import Sparte
 from bo4e.enum.tarifart import Tarifart
 from bo4e.enum.tarifmerkmal import Tarifmerkmal
 from bo4e.enum.tariftyp import Tariftyp
-from tests.serialization_helper import assert_serialization_roundtrip  # type:ignore[import]
-from tests.test_aufabschlag import example_aufabschlag  # type:ignore[import]
-from tests.test_energiemix import example_energiemix  # type:ignore[import]
-from tests.test_geraeteeigenschaften import example_geraeteeigenschaften  # type:ignore[import]
-from tests.test_marktteilnehmer import example_marktteilnehmer  # type:ignore[import]
-from tests.test_preisgarantie import example_preisgarantie  # type:ignore[import]
-from tests.test_preisposition import example_preisposition  # type:ignore[import]
-from tests.test_tarifpreisposition import example_tarifpreisposition  # type:ignore[import]
-from tests.test_vertragskonditionen import example_vertragskonditionen  # type:ignore[import]
-from tests.test_zeitraum import example_zeitraum  # type:ignore[import]
+from tests.serialization_helper import assert_serialization_roundtrip
+from tests.test_aufabschlag import example_aufabschlag
+from tests.test_energiemix import example_energiemix
+from tests.test_geraeteeigenschaften import example_geraeteeigenschaften
+from tests.test_marktteilnehmer import example_marktteilnehmer
+from tests.test_preisgarantie import example_preisgarantie
+from tests.test_preisposition import example_preisposition
+from tests.test_tarifpreisposition import example_tarifpreisposition
+from tests.test_vertragskonditionen import example_vertragskonditionen
+from tests.test_zeitraum import example_zeitraum
 
 
 class TestTarifpreisblatt:
