@@ -1,7 +1,7 @@
 from decimal import Decimal
 from typing import Any, Dict
 
-import pytest  # type:ignore[import]
+import pytest
 from pydantic import ValidationError
 
 from bo4e.com.preisstaffel import Preisstaffel
@@ -9,7 +9,7 @@ from bo4e.com.tarifpreisposition import Tarifpreisposition
 from bo4e.enum.mengeneinheit import Mengeneinheit
 from bo4e.enum.preistyp import Preistyp
 from bo4e.enum.waehrungseinheit import Waehrungseinheit
-from tests.serialization_helper import assert_serialization_roundtrip  # type:ignore[import]
+from tests.serialization_helper import assert_serialization_roundtrip
 
 example_tarifpreisposition = Tarifpreisposition(
     preistyp=Preistyp.ENTGELT_ABLESUNG,
